@@ -17,7 +17,7 @@ from typing import (
 from urllib.parse import urlencode
 
 import anyio
-from sqlalchemy import Column, asc, desc, func, inspect, or_
+from sqlalchemy import Column, String, asc, cast, desc, func, inspect, or_
 from sqlalchemy.exc import NoInspectionAvailable
 from sqlalchemy.orm import (
     ColumnProperty,
@@ -942,6 +942,18 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
             default=[item[1] for item in self._list_attrs],
         )
 
+    async def on_model_change(self, data: dict, model: Any, is_created: bool) -> None:
+        """Perform some actions before a model is created or updated.
+        By default does nothing.
+        """
+
+    async def after_model_change(
+        self, data: dict, model: Any, is_created: bool
+    ) -> None:
+        """Perform some actions after a model was created or updated and committed to the database.
+        By default does nothing.
+        """
+
     def get_column_labels(
         self,
     ) -> Dict[MODEL_ATTR_TYPE, str]:
@@ -959,6 +971,16 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
     async def update_model(self, pk: Any, data: Dict[str, Any]) -> None:
         await Query(self).update(pk, data)
 
+    async def on_model_delete(self, model: Any) -> None:
+        """Perform some actions before a model is created or updated.
+        By default does nothing.
+        """
+
+    async def after_model_delete(self, model: Any) -> None:
+        """Perform some actions before a model is deleted.
+        By default do nothing.
+        """
+
     async def scaffold_form(self) -> Type[Form]:
         if self.form is not None:
             return self.form
@@ -1004,7 +1026,9 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
         return stmt.filter(MyModel.name == term)
         ```
         """
-        expressions = [attr.ilike(f"%{term}%") for attr in self._search_fields]
+        expressions = [
+            cast(attr, String).ilike(f"%{term}%") for attr in self._search_fields
+        ]
         return stmt.filter(or_(*expressions))
 
     def get_export_name(self, export_type: str) -> str:
